You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@apr.apache.org by fu...@apache.org on 2014/07/16 17:23:38 UTC

svn commit: r1611046 - /apr/apr/trunk/threadproc/netware/thread.c

Author: fuankg
Date: Wed Jul 16 15:23:37 2014
New Revision: 1611046

URL: http://svn.apache.org/r1611046
Log:
Fixed type; fixed comments.

Modified:
    apr/apr/trunk/threadproc/netware/thread.c

Modified: apr/apr/trunk/threadproc/netware/thread.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/threadproc/netware/thread.c?rev=1611046&r1=1611045&r2=1611046&view=diff
==============================================================================
--- apr/apr/trunk/threadproc/netware/thread.c (original)
+++ apr/apr/trunk/threadproc/netware/thread.c Wed Jul 16 15:23:37 2014
@@ -82,7 +82,7 @@ apr_status_t apr_thread_create(apr_threa
                                             apr_pool_t *pool)
 {
     apr_status_t stat;
-    long flags = NX_THR_BIND_CONTEXT;
+    unsigned long flags = NX_THR_BIND_CONTEXT;
     char threadName[NX_MAX_OBJECT_NAME_LEN+1];
     size_t stack_size = APR_DEFAULT_STACK_SIZE;
 
@@ -125,8 +125,8 @@ apr_status_t apr_thread_create(apr_threa
         /* void(*start_routine)(void *arg)*/(void (*)(void *)) dummy_worker,
         /* void *arg */                                        (*new),
         /* int priority */                                     NX_PRIO_MED,
         /* NXSize_t stackSize */                               stack_size,
         /* long flags */                                       NX_CTX_NORMAL,
         /* int *error */                                       &stat);
         
                                                                            
@@ -136,7 +136,7 @@ apr_status_t apr_thread_create(apr_threa
 
     stat = NXThreadCreate(
             /* NXContext_t context */       (*new)->ctx,
             /* long flags */                flags,
             /* NXThreadId_t *thread_id */   &(*new)->td);
 
     if (stat == 0)
@@ -125,8 +125,8 @@ apr_status_t apr_thread_create(apr_threa
         /* void *arg */                                        (*new),
         /* int priority */                                     NX_PRIO_MED,
-        /* NXSize_t stackSize */                               stack_size,
-        /* long flags */                                       NX_CTX_NORMAL,
+        /* size_t stackSize */                                 stack_size,
+        /* unsigned long flags */                              NX_CTX_NORMAL,
         /* int *error */                                       &stat);
         
@@ -136,7 +136,7 @@ apr_status_t apr_thread_create(apr_threa
     stat = NXThreadCreate(
             /* NXContext_t context */       (*new)->ctx,
-            /* long flags */                flags,
+            /* unsigned long flags */       flags,
             /* NXThreadId_t *thread_id */   &(*new)->td);
 